pub struct Interner { /* private fields */ }Expand description
A set of interned names, owned by the binding.
Implementations
Sourceimpl Interner
impl Interner
Sourcepub fn intern(&mut self, name: &str) -> AtomId
pub fn intern(&mut self, name: &str) -> AtomId
Intern a name, returning the existing id if it is already known.
Sourcepub fn get(&self, name: &str) -> Option<AtomId>
pub fn get(&self, name: &str) -> Option<AtomId>
The id for a name, if it has been interned. Does not intern.