Module document_position

Module document_position 

The bit flags compare_document_position returns.

Constants

CONTAINED_BY
The other node is a descendant of this one.
CONTAINS
The other node is an ancestor of this one.
DISCONNECTED
The two nodes are in different trees.
FOLLOWING
The other node follows this one.
IMPLEMENTATION_SPECIFIC
The relative order of two disconnected nodes is arbitrary but stable.
PRECEDING
The other node precedes this one.